@@ -32,11 +32,10 @@
 #include <gdk/gdkx.h>
 #include <cairo-xlib.h>
 
-#include <gconf/gconf-client.h>
-
 #include "gsm-inhibit-dialog.h"
 #include "gsm-store.h"
 #include "gsm-client.h"
+#include "gsm-icon-names.h"
 #include "gsm-inhibitor.h"
 #include "eggdesktopfile.h"
 #include "gsm-util.h"
@@ -498,7 +497,7 @@ add_inhibitor (GsmInhibitDialog *dialog,
         }
 
         if (desktop_filename != NULL) {
-                search_dirs = gsm_util_get_desktop_dirs ();
+                search_dirs = gsm_util_get_desktop_dirs (TRUE, FALSE);
 
                 if (g_path_is_absolute (desktop_filename)) {
                         char *basename;
@@ -596,7 +595,7 @@ add_inhibitor (GsmInhibitDialog *dialog,
 
         if (pixbuf == NULL) {
                 pixbuf = _load_icon (gtk_icon_theme_get_default (),
-                                     "gnome-windows",
+                                     GSM_ICON_INHIBITOR_DEFAULT,
                                      DEFAULT_ICON_SIZE,
                                      DEFAULT_ICON_SIZE,
                                      DEFAULT_ICON_SIZE,
@@ -1099,7 +1098,7 @@ gsm_inhibit_dialog_init (GsmInhibitDialog *dialog)
         gtk_container_add (GTK_CONTAINER (content_area), widget);
 
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-        gtk_window_set_icon_name (GTK_WINDOW (dialog), "system-log-out");
+        gtk_window_set_icon_name (GTK_WINDOW (dialog), GSM_ICON_LOGOUT);
         gtk_window_set_title (GTK_WINDOW (dialog), "");
         g_object_set (dialog,
                       "resizable", FALSE,
